QueueStatus enum

The current status of the offline queue worker.

Inheritance
Available extensions

Values

idle → const QueueStatus

The worker is currently idle.

syncing → const QueueStatus

The worker is currently synchronizing requests.

paused → const QueueStatus

The worker is paused (usually due to an authentication error).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueueStatus>
A constant List of the values in this enum, in order of their declaration.